@@ -1,5 +1,6 @@
 from .archiveit_collection import ArchiveItCollection, ArchiveItCollectionException
-from .nla_collection import NLACollection, NLACollectionException
+from .trove_collection import TroveCollection, TroveCollectionException
+from .pandora_collection import PandoraCollection, PandoraSubject, PandoraCollectionException
 from .timemap import convert_LinkTimeMap_to_dict, MalformedLinkFormatTimeMap
 from .archive_information import generate_raw_urim
 from .utils import generate_archiveit_urits, process_timemaps_for_mementos, discover_raw_urims, get_uri_responses
@@ -9,7 +10,7 @@ from .version import name, version, user_agent_string
 __all__ = [ "ArchiveItCollection", "ArchiveItCollectionException",
     "convert_LinkTimeMap_to_dict", "MalformedLinkFormatTimeMap",
     "generate_raw_urim", "generate_archiveit_urits", "process_timemaps_for_mementos",
-    "discover_raw_urims", "get_uri_responses", "version", "name", "user_agent_string", "NLACollection" ]
+    "discover_raw_urims", "get_uri_responses", "version", "name", "user_agent_string", "TroveCollection", "PandoraCollection", "PandoraSubject" ]
 
 import logging
 try:  # Python 2.7+
@@ -19,4 +20,4 @@ except ImportError:
         def emit(self, record):
             pass
 
-logging.getLogger(__name__).addHandler(NullHandler())
\ No newline at end of file
+logging.getLogger(__name__).addHandler(NullHandler())
